/*  26 November 2007. UIAV Venice mobile services workshop. 
    By Nicholas Zambetti
    This code will allow user-specified text to be sent to a predetermined number
    Pressing Ok/Confirm will first allow text to be input, then sent
    Pressing 3 Key will will exit the program
    Tested on a Nokia 3230 Phone only 
*/

import processing.phone.*;      // import phone library to go fullscreen
import processing.messaging.*;  // import messaging library to send a message

Phone p;                        // named reference to phone instance
Messenger m;                    // named reference to messenger instance

PImage bg;                      // named references to graphics
PImage field;
PImage sendButton;
PImage enterMessageButton;
PImage success;

PFont font;                     // named reference to font

boolean messageSent = false;    // variable to indicate if message has been sent
String textToSend = "";         // variable to store the text (string) to be sent

void setup()                                                // when the program starts...
{
  p = new Phone(this);                                      // create new phone instance
  p.fullscreen();                                           // go fullscreen
  m = new Messenger(this);                                  // create new messenger instance
  font = loadFont("Verdana-10.mvlw", color(0,0,0));         // load the font
  textFont(font);                                           // set the font we've loaded as the default
  bg = loadImage("bg.png");                                 // load the background image
  field = loadImage("field.png");                           // load the text entry field image
  sendButton = loadImage("sendButton.png");                 // load the send message button image
  enterMessageButton = loadImage("enterMessageButton.png"); // load the enter message button image
  success = loadImage("successNotice.png");                 // load the success notice graphic
  image(bg, 0, 0);                                          // draw background image (clear the screen)
  image(field, 9, 48);                                      // draw the text entry field image
  image(enterMessageButton, 36, 157);                       // draw the enter message button

}

void draw()                     // repeatedly (according to framerate)...   
{
  if(textToSend != "")          // if text has been entered...
  {
    image(bg, 0, 0);            // draw the background iamge (clear the screen)
    image(field, 9, 48);        // draw the text entry field image
    text(textToSend, 14, 65);   // draw the text the user entered (on top of the field)
    image(sendButton, 76, 157); // draw the send button image
  }
  if(messageSent)               // message has been sent...
  {
    image(bg, 0, 0);            // draw background image (clear the screen)
    image(success, 13, 53);     // draw success notice "popup"
  }
}

void keyReleased()                                     // whenever a key is pressed...
{
  if (keyCode == FIRE)                                 // if we've pressed the center key on the directional 
  {
    if(textToSend == "")                               // if text has yet to be entered
    {
      textToSend = textInput("Your Message", "", 255); // bring up text input window and store result in variable
    }
    else {                                             // text has been entered...
      m.send("00393351341660", textToSend);            // send the entered text as a message to pre-determined phone number
      messageSent = true;                              // indicate that a message was sent
    }
  }
  if(keyCode == '3'){                                  // if we've pressed the '3' key on the numeric keypad...
    exit();                                            // exit the program
  }
}
